package com.link.core.kafka;

import com.link.base.user.model.CoreUser;
import com.link.core.kafka.conf.KafkaEnv;
import com.link.core.kafka.dynamickafka.DynamicKafkaProps;
import com.link.core.kafka.dynamickafka.KafkaProducerSource;
import com.link.core.util.RedisUtil;
import com.link.core.util.SpringUtil;
import com.link.core.util.StringUtils;
import com.link.core.util.UserUtil;
import java.util.Map;
import java.util.Objects;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.kafka.core.KafkaTemplate;
import org.springframework.kafka.support.SendResult;
import org.springframework.util.concurrent.FailureCallback;
import org.springframework.util.concurrent.ListenableFuture;
import org.springframework.util.concurrent.SuccessCallback;

public class KafkaTemplateFacotry {
   private static final Logger logger = LogManager.getLogger(KafkaTemplateFacotry.class);
   public static final String LOG_TOPIC = "KT_LOG";
   public static final String SQL_LOG_TOPIC = "KT_SQL_LOG";
   private static KafkaTemplate<String, String> KafkaTemplate;

   public static KafkaTemplate<String, String> getInstance() throws Exception {
      logger.info("获取kafkaTemplate");
      return getInstance(KafkaProducerSource.DEFAULT);
   }

   public static KafkaTemplate<String, String> getInstance(KafkaProducerSource kafkaProducerSource) throws Exception {
      logger.info("获取dynamicKafkaTemplate" + kafkaProducerSource.getName());
      Map<String, KafkaTemplate<String, String>> kafkaMap = (Map)SpringUtil.getBean("dynamicKafkaTemplate");
      if (kafkaMap.isEmpty()) {
         return getInstanceInner();
      } else {
         KafkaTemplate<String, String> kafkaTemplate = (KafkaTemplate)kafkaMap.get(kafkaProducerSource.getName());
         logger.info("获取到的dynamicKafkaTemplate：" + kafkaTemplate);
         return kafkaTemplate;
      }
   }

   public static KafkaTemplate<String, String> getInstanceInner() {
      logger.info("获取kafkaTemplate");
      return (KafkaTemplate)SpringUtil.getBean(KafkaTemplate.class);
   }

   public static void send(String topic, String message) {
      send(topic, message, "");
   }

   public static void send(String topic, String message, String key) {
      CoreUser user = UserUtil.getUser();
      String kafkaEnabled = null;
      boolean enabled = KafkaEnv.isEnabled();
      if (user != null) {
         kafkaEnabled = RedisUtil.getCropProperty("kafkaEnabled", user.getCorpid().toString());
      }

      if (kafkaEnabled != null && "N".equalsIgnoreCase(kafkaEnabled)) {
         enabled = false;
      }

      if (enabled) {
         try {
            KafkaTemplate<String, String> kafkaTemplate = getInstance();
            if (kafkaTemplate != null) {
               if (StringUtils.isNotBlank(key)) {
                  kafkaTemplate.send(topic, key, message);
               } else {
                  kafkaTemplate.send(topic, message);
               }
            }
         } catch (Exception var7) {
            Exception e = var7;
            System.out.println("发送消息失败！" + e.toString());
         }
      } else {
         System.out.println("kafka server is not avilabel! enabled->" + enabled);
      }

   }

   public static boolean send(String topic, Integer partition, String key, String message) {
      final Boolean[] isCanUse = new Boolean[]{Boolean.TRUE};
      ListenableFuture<SendResult<String, String>> future = null;

      try {
         KafkaTemplate<String, String> kafkaTemplate = getInstance();
         if (null == kafkaTemplate) {
            logger.info("发送消息失败！获取kafka实例失败");
            return false;
         } else {
            logger.info("向kafka发消息成功");
            if (StringUtils.isBlank(key)) {
               future = kafkaTemplate.send(topic, message);
            } else if (Objects.isNull(partition)) {
               future = kafkaTemplate.send(topic, key, message);
            } else {
               future = kafkaTemplate.send(topic, partition, key, message);
            }

            if (Objects.nonNull(future)) {
               future.addCallback(new SuccessCallback<SendResult<String, String>>() {
                  public void onSuccess(SendResult<String, String> stringStringSendResult) {
                     KafkaTemplateFacotry.logger.info("向kafka发消息成功");
                     isCanUse[0] = true;
                  }
               }, new FailureCallback() {
                  public void onFailure(Throwable throwable) {
                     KafkaTemplateFacotry.logger.info("向kafka发消息失败");
                     KafkaTemplateFacotry.logger.info(throwable.getMessage());
                     if (Objects.nonNull(throwable.getCause()) && throwable.getCause().toString().startsWith("org.apache.kafka.common.errors.TimeoutException")) {
                        isCanUse[0] = false;
                     }

                  }
               });
            }

            return isCanUse[0];
         }
      } catch (Exception var7) {
         Exception e = var7;
         logger.info(e.getMessage());
         return true;
      }
   }

   public static void send(String topic, String message, KafkaProducerSource kafkaProducerSource) {
      send(topic, (String)message, (String)null, (KafkaProducerSource)kafkaProducerSource);
   }

   public static void send(String topic, String message, String key, KafkaProducerSource kafkaProducerSource) {
      try {
         CoreUser user = UserUtil.getUser();
         String kafkaEnabled = null;
         boolean enabled = KafkaEnv.isEnabled();
         if (user != null) {
            kafkaEnabled = RedisUtil.getCorpProperty("kafkaEnabled", user.getCorpid());
         }

         if (kafkaEnabled != null && "N".equalsIgnoreCase(kafkaEnabled)) {
            enabled = false;
         }

         if (enabled) {
            Exception e;
            try {
               e = null;
               DynamicKafkaProps dynamicKafkaProps = (DynamicKafkaProps)SpringUtil.getBean(DynamicKafkaProps.class);
               KafkaTemplate kafkaTemplate;
               if (null != dynamicKafkaProps && dynamicKafkaProps.getEnable()) {
                  if (null == kafkaProducerSource) {
                     kafkaTemplate = getInstance(KafkaProducerSource.DEFAULT);
                  } else {
                     kafkaTemplate = getInstance(kafkaProducerSource);
                  }
               } else {
                  kafkaTemplate = getInstance();
               }

               if (kafkaTemplate != null) {
                  if (StringUtils.isNotBlank(key)) {
                     kafkaTemplate.send(topic, key, message);
                  } else {
                     kafkaTemplate.send(topic, message);
                  }
               }
            } catch (Exception var9) {
               e = var9;
               System.out.println("发送消息失败！" + e.toString());
            }
         } else {
            System.out.println("kafka server is not avilabel! enabled->" + enabled);
         }
      } catch (Exception var10) {
         Exception exception = var10;
         logger.error(exception.getMessage(), exception);
      }

   }
}
